@@ -184,7 +184,7 @@ void *ssl_config_server_create(pool *p, server_rec *s)
     sc->nSessionCacheTimeout   = UNSET;
     sc->nPassPhraseDialogType  = SSL_PPTYPE_UNSET;
     sc->szPassPhraseDialogPath = NULL;
-
+    sc->nProtocol              = SSL_PROTOCOL_ALL;
     sc->fileLogFile            = NULL;
     sc->px509Certificate       = NULL;
     sc->prsaKey                = NULL;
@@ -215,7 +215,7 @@ void *ssl_config_server_merge(pool *p, void *basev, void *addv)
     cfgMergeInt(nSessionCacheTimeout);
     cfgMerge(nPassPhraseDialogType, SSL_PPTYPE_UNSET);
     cfgMergeString(szPassPhraseDialogPath);
-
+    cfgMerge(nProtocol, SSL_PROTOCOL_ALL);
     cfgMerge(fileLogFile, NULL);
     cfgMerge(px509Certificate, NULL);
     cfgMerge(prsaKey, NULL);
@@ -681,3 +681,42 @@ const char *ssl_cmd_SSLRequire(
     return NULL;
 }
 
+const char *ssl_cmd_SSLProtocol(
+    cmd_parms *cmd, char *struct_ptr, const char *opt)
+{
+    SSLSrvConfigRec *sc;
+    ProtocolType options, thisopt;
+    char action;
+    char *w;
+
+    sc = mySrvConfig(cmd->server);
+    options = SSL_PROTOCOL_NONE;
+    while (opt[0] != NUL) {
+        w = ap_getword_conf(cmd->pool, &opt);
+
+        action = NUL;
+        if (*w == '+' || *w == '-')
+            action = *(w++);
+
+        if (strcEQ(w, "SSLv2"))
+            thisopt = SSL_PROTOCOL_SSLV2;
+        else if (strcEQ(w, "SSLv3"))
+            thisopt = SSL_PROTOCOL_SSLV3;
+        else if (strcEQ(w, "TLSv1"))
+            thisopt = SSL_PROTOCOL_TLSV1;
+        else if (strcEQ(w, "all"))
+            thisopt = SSL_PROTOCOL_ALL;
+        else
+            return ap_pstrcat(cmd->pool, "SSLProtocol: Illegal protocol '", w, "'", NULL);
+
+        if (action == '-')
+            options &= ~thisopt;
+        else if (action == '+')
+            options |= thisopt;
+        else
+            options = thisopt;
+    }
+    sc->nProtocol = options;
+    return NULL;
+}
+
