@@ -536,7 +536,7 @@ int ssl_hook_Auth(request_rec *r)
         return DECLINED;
     if (r->connection->user)
         return DECLINED;
-    if ((clientdn = (char *)ap_ctx_get(r->connection->client->ctx, "ssl:client::dn")) == NULL)
+    if ((clientdn = (char *)ap_ctx_get(r->connection->client->ctx, "ssl::client::dn")) == NULL)
         return DECLINED;
 
     /*
