@@ -81,7 +81,7 @@ void ssl_pphrase_Handle(server_rec *s, pool *p)
     SSLModConfigRec *mc = myModConfig();
     SSLSrvConfigRec *sc;
     server_rec *pServ;
-    char *cpServerName;
+    char *cpVHostID;
     char szPath[MAX_STRING_LEN];
     RSA *pRSAKey;
     RSA **ppRSAKey;
@@ -115,8 +115,10 @@ void ssl_pphrase_Handle(server_rec *s, pool *p)
         if (!sc->bEnabled)
             continue;
 
-        cpServerName = ap_psprintf(p, "%s:%d", pServ->server_hostname, pServ->port);
-        ssl_log(pServ, SSL_LOG_INFO, "Init: Loading certificate & private key of SSL-aware server %s", cpServerName);
+        cpVHostID = ssl_util_vhostid(p, pServ);
+        ssl_log(pServ, SSL_LOG_INFO, 
+                "Init: Loading certificate & private key of SSL-aware server %s", 
+                cpVHostID);
 
         /*
          * Read in server certificate: This is the easy part
@@ -125,7 +127,7 @@ void ssl_pphrase_Handle(server_rec *s, pool *p)
         if (sc->szCertificateFile == NULL) {
             ssl_log(pServ, SSL_LOG_ERROR,
                     "Init: Server %s should be SSL-aware but has no certificate configured "
-                    "[Hint: SSLCertifcateFile]", cpServerName);
+                    "[Hint: SSLCertifcateFile]", cpVHostID);
             ssl_die();
         }
         ap_cpystrn(szPath, sc->szCertificateFile, sizeof(szPath));
@@ -149,7 +151,7 @@ void ssl_pphrase_Handle(server_rec *s, pool *p)
          * certificate is actually used to configure mod_ssl's per-server
          * configuration structures).
          */
-        ppX509Cert = ssl_ds_table_push(mc->tPublicCert, cpServerName);
+        ppX509Cert = ssl_ds_table_push(mc->tPublicCert, cpVHostID);
         *ppX509Cert = pX509Cert;
 
         /*
@@ -180,7 +182,7 @@ void ssl_pphrase_Handle(server_rec *s, pool *p)
         myCtxVarSet(mc, 3, aPassPhrase);
         myCtxVarSet(mc, 4, &nPassPhraseCur);
         myCtxVarSet(mc, 5, &cpPassPhraseCur);
-        myCtxVarSet(mc, 6, cpServerName);
+        myCtxVarSet(mc, 6, cpVHostID);
         myCtxVarSet(mc, 7, &nPassPhraseDialog);
         myCtxVarSet(mc, 8, &nPassPhraseDialogCur);
         myCtxVarSet(mc, 9, &bPassPhraseDialogOnce);
@@ -261,16 +263,16 @@ void ssl_pphrase_Handle(server_rec *s, pool *p)
         if (nPassPhraseDialogCur == 0)
             ssl_log(pServ, SSL_LOG_TRACE,
                     "Init: (%s) unencrypted private key - pass phrase not required",
-                    cpServerName);
+                    cpVHostID);
         else {
             if (cpPassPhraseCur != NULL)
                 ssl_log(pServ, SSL_LOG_TRACE,
                         "Init: (%s) encrypted private key - pass phrase requested",
-                        cpServerName);
+                        cpVHostID);
             else
                 ssl_log(pServ, SSL_LOG_TRACE,
                         "Init: (%s) encrypted private key - pass phrase reused",
-                        cpServerName);
+                        cpVHostID);
         }
 
         /*
@@ -285,7 +287,7 @@ void ssl_pphrase_Handle(server_rec *s, pool *p)
         /*
          * Insert private key into the global module configuration
          */
-        ppRSAKey = ssl_ds_table_push(mc->tPrivateKey, cpServerName);
+        ppRSAKey = ssl_ds_table_push(mc->tPrivateKey, cpVHostID);
         *ppRSAKey = pRSAKey;
     }
 
@@ -322,7 +324,7 @@ int ssl_pphrase_Handle_CB(char *buf, int bufsize, int w)
     SSLSrvConfigRec *sc;
     int *pnPassPhraseCur;
     char **cppPassPhraseCur;
-    char *cpServerName;
+    char *cpVHostID;
     int *pnPassPhraseDialog;
     int *pnPassPhraseDialogCur;
     BOOL *pbPassPhraseDialogOnce;
@@ -337,7 +339,7 @@ int ssl_pphrase_Handle_CB(char *buf, int bufsize, int w)
     aPassPhrase            = myCtxVarGet(mc, 3, ssl_ds_array *);
     pnPassPhraseCur        = myCtxVarGet(mc, 4, int *);
     cppPassPhraseCur       = myCtxVarGet(mc, 5, char **);
-    cpServerName           = myCtxVarGet(mc, 6, char *);
+    cpVHostID              = myCtxVarGet(mc, 6, char *);
     pnPassPhraseDialog     = myCtxVarGet(mc, 7, int *);
     pnPassPhraseDialogCur  = myCtxVarGet(mc, 8, int *);
     pbPassPhraseDialogOnce = myCtxVarGet(mc, 9, BOOL *);
@@ -388,7 +390,7 @@ int ssl_pphrase_Handle_CB(char *buf, int bufsize, int w)
         if (*pbPassPhraseDialogOnce) {
             *pbPassPhraseDialogOnce = FALSE;
             fprintf(stderr, "\n");
-            fprintf(stderr, "Server %s\n", cpServerName);
+            fprintf(stderr, "Server %s\n", cpVHostID);
         }
 
         /*
@@ -426,7 +428,7 @@ int ssl_pphrase_Handle_CB(char *buf, int bufsize, int w)
                 "Init: Requesting pass phrase from dialog filter program (%s)",
                 sc->szPassPhraseDialogPath);
 
-        cmd = ap_psprintf(p, "%s %s", sc->szPassPhraseDialogPath, cpServerName);
+        cmd = ap_psprintf(p, "%s %s", sc->szPassPhraseDialogPath, cpVHostID);
         result = ssl_util_readfilter(s, p, cmd);
         ap_cpystrn(buf, result, bufsize);
         len = strlen(buf);
